@@ -23,7 +23,6 @@ import org.apache.cayenne.exp.Expression;
 import org.apache.cayenne.exp.ExpressionFactory;
 import org.apache.cayenne.map.DbEntity;
 import org.apache.cayenne.query.ObjectSelect;
-import org.apache.cayenne.query.SelectQuery;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
 import org.apache.cayenne.testdo.qualified.Qualified1;
@@ -113,8 +112,79 @@ public class CDOQualifiedEntitiesIT extends ServerCase {
 
             createReadToManyDataSet();
 
-            SelectQuery rootSelect = new SelectQuery(Qualified1.class);
-            List<Qualified1> roots = context.performQuery(rootSelect);
+            List<Qualified1> roots = ObjectSelect.query(Qualified1.class).select(context);
+
+            assertEquals(1, roots.size());
+
+            Qualified1 root = roots.get(0);
+
+            assertEquals("OX1", root.getName());
+
+            List<Qualified2> related = root.getQualified2s();
+            assertEquals(1, related.size());
+
+            Qualified2 r = related.get(0);
+            assertEquals("OY1", r.getName());
+        }
+    }
+
+    @Test
+    public void testJointPrefetchToMany() throws Exception {
+        if (accessStackAdapter.supportsNullBoolean()) {
+
+            createReadToManyDataSet();
+
+            List<Qualified1> roots = ObjectSelect.query(Qualified1.class)
+                    .prefetch(Qualified1.QUALIFIED2S.joint())
+                    .select(context);
+
+            assertEquals(1, roots.size());
+
+            Qualified1 root = roots.get(0);
+
+            assertEquals("OX1", root.getName());
+
+            List<Qualified2> related = root.getQualified2s();
+            assertEquals(1, related.size());
+
+            Qualified2 r = related.get(0);
+            assertEquals("OY1", r.getName());
+        }
+    }
+
+    @Test
+    public void testDisjointPrefetchToMany() throws Exception {
+        if (accessStackAdapter.supportsNullBoolean()) {
+
+            createReadToManyDataSet();
+
+            List<Qualified1> roots = ObjectSelect.query(Qualified1.class)
+                    .prefetch(Qualified1.QUALIFIED2S.disjoint())
+                    .select(context);
+
+            assertEquals(1, roots.size());
+
+            Qualified1 root = roots.get(0);
+
+            assertEquals("OX1", root.getName());
+
+            List<Qualified2> related = root.getQualified2s();
+            assertEquals(1, related.size());
+
+            Qualified2 r    = related.get(0);
+            assertEquals("OY1", r.getName());
+        }
+    }
+
+    @Test
+    public void testDisjointByIdPrefetchToMany() throws Exception {
+        if (accessStackAdapter.supportsNullBoolean()) {
+
+            createReadToManyDataSet();
+
+            List<Qualified1> roots = ObjectSelect.query(Qualified1.class)
+                    .prefetch(Qualified1.QUALIFIED2S.disjointById())
+                    .select(context);
 
             assertEquals(1, roots.size());
 
@@ -136,8 +206,7 @@ public class CDOQualifiedEntitiesIT extends ServerCase {
 
             createReadToOneDataSet();
 
-            SelectQuery rootSelect = new SelectQuery(Qualified2.class);
-            List<Qualified2> roots = context.performQuery(rootSelect);
+            List<Qualified2> roots = ObjectSelect.query(Qualified2.class).select(context);
             assertEquals(1, roots.size());
 
             Qualified2 root = roots.get(0);
